@@ -20,10 +20,10 @@
 #include "context.h"
 
 
-u_long id = 1058309664;
 uint32_t version = 0;
 u_long options = BE_SFX2D|BEQ_NORANDOM;
 char desc[] = "Pulsing box";
+char dname[] = "Bass line";
 
 #define BEAT_BAND 2
 
