@@ -20,12 +20,11 @@
 #include "context.h"
 
 
-u_long id = 1100375479;
 uint32_t version = 0;
 u_long options = BE_SFX2D|BEQ_NORANDOM;
 u_long mode = OVERLAY;
 char desc[] = "Critters demo";
-
+char dname[] = "Critters";
 
 struct Critter {
   Pixel_t color;     /* critter color */
@@ -114,7 +113,7 @@ create(Context_t *ctx)
   nb_critters = ctx->input->size;
 
   critters = xcalloc(nb_critters, sizeof(struct Critter));
-  if (critters == NULL) {
+  if (NULL == critters) {
     xerror("pas de critter, trop dure la vie\n");
   }
 
@@ -127,7 +126,7 @@ create(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  if (critters != NULL) {
+  if (NULL != critters) {
     xfree(critters);
   }
 }
