@@ -34,7 +34,7 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
   int border_mode_idx = 0;
   if (plugin_parameter_parse_string_list_as_int_range(in_parameters, BPP_BORDER_MODE, BM_NB, border_list, &border_mode_idx, 0, BM_NB-1)) {
@@ -44,9 +44,11 @@ set_parameters(const json_t *in_parameters)
 
 
 json_t *
-parameters(json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
