@@ -21,7 +21,7 @@
 #ifndef __GUM_H
 #define __GUM_H
 
-static float volume_scale = 0;
+static double volume_scale = 0;
 
 json_t *
 get_parameters()
@@ -34,16 +34,18 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  plugin_parameter_parse_float_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 1);
+  plugin_parameter_parse_double_range(in_parameters, BPP_VOLUME_SCALE, &volume_scale, 0, 1);
 }
 
 
 json_t *
-parameters(json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
