@@ -25,7 +25,6 @@
 #include "context.h"
 #include "parameters.h"
 
-u_long id = 1567343672;
 uint32_t version = 0;
 u_long options = BE_GFX | BE_SFX2D;
 u_long mode = OVERLAY;
@@ -50,18 +49,19 @@ static u_short nb_rotors, min_color, max_color;
 static float freq_base_moy, freq_base_ect;
 static float freq_var_moy, freq_var_ect;
 static float ampl_var_moy, ampl_var_ect;
-static float proba_visible, rotor_time;
+static float rotor_time;
 static int max_prof;
 
 static Rotor tab[MAX_ROTORS];
 static float time_step;
 
 static int nb_min_rotors = 0;
-static float length_min = 0;
-static float length_max = 0;
-static float spectrum_id_factor = 0;
-static float speed = 0;
-static float scale = 0;
+static double proba_visible = 0;
+static double length_min = 0;
+static double length_max = 0;
+static double spectrum_id_factor = 0;
+static double speed = 0;
+static double scale = 0;
 
 static void post_init();
 
@@ -82,23 +82,23 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
   int reload = 0;
   reload |= plugin_parameter_parse_int_range(in_parameters, BPP_NB_MIN_ROTORS, &nb_min_rotors, 0, 1) & PLUGIN_PARAMETER_CHANGED;
-  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_PROBA_VISIBLE, &proba_visible, 0, 1) & PLUGIN_PARAMETER_CHANGED;
+  reload |= plugin_parameter_parse_double_range(in_parameters, BPP_PROBA_VISIBLE, &proba_visible, 0, 1) & PLUGIN_PARAMETER_CHANGED;
 
-  float __length_min = length_min, __length_max = length_max;
-  plugin_parameter_parse_float_range(in_parameters, BPP_LENGTH_MIN, &__length_min, 0.01, 0.2);
-  plugin_parameter_parse_float_range(in_parameters, BPP_LENGTH_MAX, &__length_max, 0.02, 10);
+  double __length_min = length_min, __length_max = length_max;
+  plugin_parameter_parse_double_range(in_parameters, BPP_LENGTH_MIN, &__length_min, 0.01, 0.2);
+  plugin_parameter_parse_double_range(in_parameters, BPP_LENGTH_MAX, &__length_max, 0.02, 10);
   if (__length_min <= __length_max) {
     length_min = __length_min;
     length_max = __length_max;
   }
 
-  plugin_parameter_parse_float_range(in_parameters, BPP_SPECTRUM_ID_FACTOR, &spectrum_id_factor, 0, 20);
-  plugin_parameter_parse_float_range(in_parameters, BPP_SPEED, &speed, -10, 10);
-  reload |= plugin_parameter_parse_float_range(in_parameters, BPP_SCALE, &scale, 0, 2) & PLUGIN_PARAMETER_CHANGED;
+  plugin_parameter_parse_double_range(in_parameters, BPP_SPECTRUM_ID_FACTOR, &spectrum_id_factor, 0, 20);
+  plugin_parameter_parse_double_range(in_parameters, BPP_SPEED, &speed, -10, 10);
+  reload |= plugin_parameter_parse_double_range(in_parameters, BPP_SCALE, &scale, 0, 2) & PLUGIN_PARAMETER_CHANGED;
 
   if (reload) {
     post_init();
@@ -107,9 +107,11 @@ set_parameters(const json_t *in_parameters)
 
 
 json_t *
-parameters(const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
@@ -122,7 +124,7 @@ prof_rotor_tree(Rotor *rotor)
 {
   int pg, pd;
 
-  if (rotor == NULL) {
+  if (NULL == rotor) {
     return 0;
   }
 
@@ -158,9 +160,9 @@ build_rotor_tree()
 
     /* Le resultat de la roulette est dans 'j' */
     arite[j]--;
-    if (tab[j].fg == NULL) {
+    if (NULL == tab[j].fg) {
       tab[j].fg = tab + i;
-    } else if (tab[j].fd == NULL) {
+    } else if (NULL == tab[j].fd) {
       tab[j].fd = tab + i;
     }
     arite[i] = 2;
@@ -177,10 +179,10 @@ init_rotor_tree(Rotor *rotor, float max_ray)
   int prof = prof_rotor_tree(rotor);
 
   rotor->rayon = (drand48() * (max_rnd_factor - min_rnd_factor) + min_rnd_factor) * (float)max_ray / (float)prof;
-  if (rotor->fg != NULL) {
+  if (NULL != rotor->fg) {
     init_rotor_tree(rotor->fg, max_ray - rotor->rayon);
   }
-  if (rotor->fd != NULL) {
+  if (NULL != rotor->fd) {
     init_rotor_tree(rotor->fd, max_ray - rotor->rayon);
   }
 }
@@ -306,7 +308,7 @@ create(Context_t *ctx)
 static void
 refresh(Rotor *rotor)
 {
-  if ((rotor->fg != NULL) || (rotor->fd != NULL))  {
+  if ((NULL != rotor->fg) || (NULL != rotor->fd))  {
     float f, arg, alpha;
     _Complex float pos_rel;
 
@@ -317,11 +319,11 @@ refresh(Rotor *rotor)
 
     pos_rel = rotor->rayon * cexp(ci * alpha);
 
-    if (rotor->fg != NULL) {
+    if (NULL != rotor->fg) {
       rotor->fg->centre = rotor->centre + pos_rel;
       refresh(rotor->fg);
     }
-    if (rotor->fd != NULL) {
+    if (NULL != rotor->fd) {
       rotor->fd->centre = rotor->centre - pos_rel;
       refresh(rotor->fd);
     }
