@@ -31,23 +31,22 @@
 #include "context.h"
 #include "parameters.h"
 
-u_long id = 1555581982;
 
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_UNIQUE|BE_SFX2D;
 
 u_long mode = OVERLAY;
 
-char dname[] = "snake";
+char dname[] = "Snake";
 char desc[] = "Snake";
 
 static u_short x = 0, y = 0;
 
 static int snake_mode = 0;
-static float length_min = 0; /* minimum length of the snake, in pixels, scales with WIDTH */
-static float length_max = 0; /* maximum length of the snake, in pixels, scales with WIDTH */
-static float spectrum_id_factor = 0;
-static float color_factor = 0; /* scaling of the computed color */
+static double length_min = 0; /* minimum length of the snake, in pixels, scales with WIDTH */
+static double length_max = 0; /* maximum length of the snake, in pixels, scales with WIDTH */
+static double spectrum_id_factor = 0;
+static double color_factor = 0; /* scaling of the computed color */
 
 json_t *
 get_parameters()
@@ -64,27 +63,29 @@ get_parameters()
 
 
 void
-set_parameters(const json_t *in_parameters)
+set_parameters(const Context_t *ctx, const json_t *in_parameters)
 {
   plugin_parameter_parse_int_range(in_parameters, BPP_MODE, &snake_mode, 0, 2);
 
-  float __length_min = length_min, __length_max = length_max;
-  plugin_parameter_parse_float_range(in_parameters, BPP_LENGTH_MIN, &__length_min, 0.01, 0.2);
-  plugin_parameter_parse_float_range(in_parameters, BPP_LENGTH_MAX, &__length_max, 0.02, 0.5);
+  double __length_min = length_min, __length_max = length_max;
+  plugin_parameter_parse_double_range(in_parameters, BPP_LENGTH_MIN, &__length_min, 0.01, 0.2);
+  plugin_parameter_parse_double_range(in_parameters, BPP_LENGTH_MAX, &__length_max, 0.02, 0.5);
   if (__length_min <= __length_max) {
     length_min = __length_min;
     length_max = __length_max;
   }
 
-  plugin_parameter_parse_float_range(in_parameters, BPP_SPECTRUM_ID_FACTOR, &spectrum_id_factor, 0, 4);
-  plugin_parameter_parse_float_range(in_parameters, BPP_COLOR_FACTOR, &color_factor, 0, 5);
+  plugin_parameter_parse_double_range(in_parameters, BPP_SPECTRUM_ID_FACTOR, &spectrum_id_factor, 0, 4);
+  plugin_parameter_parse_double_range(in_parameters, BPP_COLOR_FACTOR, &color_factor, 0, 5);
 }
 
 
 json_t *
-parameters(const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters)
 {
-  set_parameters(in_parameters);
+  if (NULL != in_parameters) {
+    set_parameters(ctx, in_parameters);
+  }
 
   return get_parameters();
 }
