@@ -24,10 +24,11 @@
                              to be shown. Lower values show target better,
                              but also show more flickering */
 
-u_long id = 1552077700;
 uint32_t version = 0;
 u_long options = BE_GFX|BE_LENS|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "Show cam pic which differs";
+char dname[] = "TV diff 3";
+
 u_long mode = OVERLAY;
 
 
