@@ -37,10 +37,11 @@
 #define CURVE_START    2   /* CURVE_START * CURVE_VOL_MULT needs to be > 2,
                               so we need at least 2 */
 
-u_long id = 1552382051;
 uint32_t version = 0;
 u_long options = BE_GFX|BE_LENS|BE_SFX2D|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "Show cam pic which differs, react beat";
+char dname[] = "TV diff beat";
+
 u_long mode = OVERLAY;
 
 
