@@ -32,10 +32,11 @@
 #include "context.h"
 
 
-u_long id = 1325194798;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_IMAGE|BEQ_MUTE_CAM;
 char desc[] = "NervousTV plugin from the EffecTV project";
+char dname[] = "TV nervous";
+
 u_long mode = OVERLAY;
 
 #define PLANES 8
