@@ -28,10 +28,11 @@
 #include "context.h"
 
 
-u_long id = 1325445400;
 uint32_t version = 0;
 u_long options = BE_GFX|BEQ_IMAGE|BEQ_MUTE_CAM|BEQ_NORANDOM;
 char desc[] = "PredatorTV plugin from the EffecTV project";
+char dname[] = "TV predator";
+
 u_long mode = OVERLAY;
 
 #define MAGIC_THRESHOLD 40
