@@ -30,7 +30,7 @@
 #define B_INIT_ALL          (B_INIT_SEQUENCES|B_INIT_SCHEMES)
 
 void biniou_new(const char *, const char *, const char *, const char *,
-                const u_char, const uint32_t, const uint8_t, const uint8_t, const int);
+                const u_char, const uint32_t, const int);
 void biniou_delete();
 
 /* vla le bordel */
