@@ -135,7 +135,7 @@ getargs(int argc, char **argv)
 #endif
     switch (ch) {
       case 'b':
-        if (base_dir == NULL) {
+        if (NULL == base_dir) {
           base_dir = optarg;
         }
         break;
@@ -158,13 +158,13 @@ getargs(int argc, char **argv)
 #endif
 
       case 'd':
-        if (data_dir == NULL) {
+        if (NULL == data_dir) {
           data_dir = optarg;
         }
         break;
 
       case 'z':
-        if (schemes_file == NULL) {
+        if (NULL == schemes_file) {
           schemes_file = optarg;
         }
         break;
@@ -272,7 +272,7 @@ getargs(int argc, char **argv)
         break;
 
       case 'p':
-        if (pid_file == NULL) {
+        if (NULL == pid_file) {
           pid_file = optarg;
         }
         break;
