@@ -55,7 +55,7 @@ Context_process_event(Context_t *ctx, const Event_t *e)
       break;
 
     case BT_SEQMGR:
-      (void)SequenceManager_event(ctx->sm, e, ctx->auto_colormaps, ctx->auto_images);
+      (void)SequenceManager_event(ctx, e, ctx->auto_colormaps, ctx->auto_images);
       break;
 
     case BT_PLUGINS:
@@ -75,7 +75,7 @@ Context_process_events(Context_t *ctx)
 {
   GList *t;
 
-  for (t = ctx->events; t != NULL; t = g_list_next(t)) {
+  for (t = ctx->events; NULL != t; t = g_list_next(t)) {
     Event_t *e = (Event_t *)t->data;
 
     Context_process_event(ctx, e);
@@ -106,13 +106,11 @@ int
 Context_event(Context_t *ctx, const Event_t *e)
 {
   GSList *outputs = ctx->outputs;
-  uint8_t delay; // current phase-space delay
-  uint8_t span; // spline span size
 
   switch (e->cmd) {
     case BC_QUIT:
       if (e->arg0 == BA_SAVE)
-        Sequence_save(ctx->sm->cur, 0, SequenceManager_is_transient(ctx->sm, ctx->sm->cur),
+        Sequence_save(ctx, ctx->sm->cur, 0, SequenceManager_is_transient(ctx->sm, ctx->sm->cur),
                       TRUE, ctx->auto_colormaps, ctx->auto_images);
       ctx->running = 0;
       return 1;
@@ -128,7 +126,7 @@ Context_event(Context_t *ctx, const Event_t *e)
     case BC_SWITCH:
       switch (e->arg0) {
         case BA_SELECTED:
-          if (Sequence_find(ctx->sm->cur, plugins->selected) != NULL) {
+          if (NULL != Sequence_find(ctx->sm->cur, plugins->selected)) {
             Context_remove_plugin(ctx, plugins->selected);
           } else {
             if (g_list_length(ctx->sm->cur->layers) < MAX_SEQ_LEN) {
@@ -141,27 +139,27 @@ Context_event(Context_t *ctx, const Event_t *e)
           ctx->fullscreen = !ctx->fullscreen;
           printf("[S] Full-screen %s\n", ctx->fullscreen ? "off" : "on");
 
-          for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
+          for ( ; NULL != outputs; outputs = g_slist_next(outputs)) {
             Plugin_t *output = (Plugin_t *)outputs->data;
 
-            if (output->fullscreen != NULL) {
+            if (NULL != output->fullscreen) {
               output->fullscreen(ctx->fullscreen);
             }
           }
           return 1;
 
         case BA_CURSOR:
-          for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
+          for ( ; NULL != outputs; outputs = g_slist_next(outputs)) {
             Plugin_t *output = (Plugin_t *)outputs->data;
 
-            if (output->switch_cursor != NULL) {
+            if (NULL != output->switch_cursor) {
               output->switch_cursor();
             }
           }
           return 1;
 
         case BA_COLORMAPS:
-          if ((colormaps != NULL) && (colormaps->size > 1)) {
+          if ((NULL != colormaps) && (colormaps->size > 1)) {
             ctx->sm->cur->auto_colormaps = ctx->auto_colormaps = !ctx->auto_colormaps;
             Sequence_changed(ctx->sm->cur);
             Context_update_auto(ctx);
@@ -171,7 +169,7 @@ Context_event(Context_t *ctx, const Event_t *e)
           }
 
         case BA_IMAGES:
-          if ((images != NULL) && (images->size > 1)) {
+          if ((NULL != images) && (images->size > 1)) {
             ctx->sm->cur->auto_images = ctx->auto_images = !ctx->auto_images;
             Sequence_changed(ctx->sm->cur);
             Context_update_auto(ctx);
@@ -231,7 +229,7 @@ Context_event(Context_t *ctx, const Event_t *e)
           }
 
           if (ctx->random_mode == BR_SCHEMES) {
-            if ((schemes == NULL) || (!Shuffler_ok(schemes->shuffler))) {
+            if ((NULL == schemes) || (!Shuffler_ok(schemes->shuffler))) {
               printf("[i] Skipping random schemes since there are no schemes available\n");
               ctx->random_mode = BR_SEQUENCES;
             } else {
@@ -241,7 +239,7 @@ Context_event(Context_t *ctx, const Event_t *e)
           }
 
           if (ctx->random_mode == BR_SEQUENCES) {
-            if ((sequences->seqs == NULL) || !g_list_length(sequences->seqs)) {
+            if ((NULL == sequences->seqs) || !g_list_length(sequences->seqs)) {
               printf("[i] Skipping random sequences since there are no sequences available\n");
               ctx->random_mode = BR_NONE;
             } else {
@@ -253,20 +251,6 @@ Context_event(Context_t *ctx, const Event_t *e)
           Context_display_random(ctx);
           return 1;
 
-        case BA_DELAY:
-          if ((delay = Context_get_phase_space_delay(ctx)) > 1) {
-            Context_set_phase_space_delay(ctx, --delay);
-            printf("[i] Phase-space delay: %d\n", delay);
-          }
-          return 1;
-
-        case BA_SPAN:
-          if ((span = Context_get_span_size(ctx)) > 1) {
-            Context_set_span_size(ctx, --span);
-            printf("[i] Spline span size: %d\n", span);
-          }
-          return 1;
-
         default:
           return 0;
       }
@@ -283,10 +267,10 @@ Context_event(Context_t *ctx, const Event_t *e)
           return 1;
 
         case BA_RANDOM:
-          ctx->random_mode = (enum RandomMode)((ctx->random_mode+1) % sizeof(RandomMode_e));
+          ctx->random_mode = (ctx->random_mode + 1) % BR_NB;
 
           if (ctx->random_mode == BR_SEQUENCES) {
-            if ((sequences->seqs == NULL) || !g_list_length(sequences->seqs)) {
+            if ((NULL == sequences->seqs) || !g_list_length(sequences->seqs)) {
               printf("[i] Skipping random sequences since there are no sequences available\n");
               ctx->random_mode = BR_SCHEMES;
             } else {
@@ -296,7 +280,7 @@ Context_event(Context_t *ctx, const Event_t *e)
           }
 
           if (ctx->random_mode == BR_SCHEMES) {
-            if ((schemes == NULL) || (!Shuffler_ok(schemes->shuffler))) {
+            if ((NULL == schemes) || (!Shuffler_ok(schemes->shuffler))) {
               printf("[i] Skipping random schemes since there are no schemes available\n");
               ctx->random_mode = BR_BOTH;
             } else {
@@ -318,20 +302,6 @@ Context_event(Context_t *ctx, const Event_t *e)
           return 1;
 #endif
 
-        case BA_DELAY:
-          if ((delay = Context_get_phase_space_delay(ctx)) < 255) {
-            Context_set_phase_space_delay(ctx, ++delay);
-            printf("[i] Phase-space delay: %d\n", delay);
-          }
-          return 1;
-
-        case BA_SPAN:
-          if ((span = Context_get_span_size(ctx)) < 50) {
-            Context_set_span_size(ctx, ++span);
-            printf("[i] Spline span size: %d\n", span);
-          }
-          return 1;
-
         default:
           return 0;
       }
@@ -340,7 +310,7 @@ Context_event(Context_t *ctx, const Event_t *e)
     case BC_RANDOM:
       switch (e->arg0) {
         case BA_SEQUENCE:
-          assert(sequences != NULL);
+          assert(NULL != sequences);
 
           if (sequences->size > 1) {
             Context_random_sequence(ctx);
@@ -349,7 +319,7 @@ Context_event(Context_t *ctx, const Event_t *e)
           return 1;
 
         case BA_SCHEME:
-          if ((schemes != NULL) && (schemes->size > 1)) {
+          if ((NULL != schemes) && (schemes->size > 1)) {
             Schemes_random(ctx);
             Alarm_init(ctx->a_random);
           }
