@@ -84,16 +84,16 @@ Context_sequence(Context_t *ctx)
   ctx->texture_ready = ctx->texture_used = ctx->gl_done = 0;
 #endif
 
-  while (tmp != NULL) {
+  while (NULL != tmp) {
     Layer_t *layer = (Layer_t *)tmp->data;
     Plugin_t *P = layer->plugin;
 
-    assert(P != NULL);
+    assert(NULL != P);
     if (P == ctx->sm->cur->lens) {
       push_buffer(ctx);
     }
 
-    if (P->run != NULL)
+    if (NULL != P->run)
       if (!ctx->bypass || (ctx->bypass && !(*P->options & BEQ_MUTE_CAM))) {
         P->run(ctx);
         P->calls++;
@@ -178,7 +178,7 @@ Context_run(Context_t *ctx)
   }
 
   /* Auto-change image */
-  if (ctx->imgf != NULL) {
+  if (NULL != ctx->imgf) {
     /* Timer elapsed ? */
     if (ctx->imgf->on && Alarm_ring(ctx->a_images)) {
       ImageFader_random(ctx->imgf);
@@ -218,7 +218,7 @@ Context_run(Context_t *ctx)
     input->run(ctx);
     input->calls++;
   }
-  if (ctx->input != NULL) {
+  if (NULL != ctx->input) {
     Input_process(ctx->input);
   }
 
@@ -267,17 +267,17 @@ Context_run(Context_t *ctx)
 
   /* show the current colormap */
   if (ctx->display_colormap) {
-    if (ctx->sm->cur->lens == NULL) {
+    if (NULL == ctx->sm->cur->lens) {
       push_buffer(ctx);
     }
     Buffer8_color_bar(active_buffer(ctx), BARSIZE);
   }
 
-  for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
+  for ( ; NULL != outputs; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
 
     /* TODO print a warning: an output plugin without run() is a bug */
-    if (output->run != NULL) {
+    if (NULL != output->run) {
       output->run(ctx);
       output->calls++;
     }
@@ -293,7 +293,7 @@ Context_run(Context_t *ctx)
   }
 
   /* Restore possibly saved buffer */
-  if ((ctx->sm->cur->lens != NULL) || ctx->display_colormap) {
+  if ((NULL != ctx->sm->cur->lens) || ctx->display_colormap) {
     pop_buffer(ctx);
   }
 
