@@ -42,12 +42,7 @@ uint8_t statistics = 0; // Display statistics
 /* default input size (samples) */
 #define DEFAULT_INPUT_SIZE 1024
 uint32_t input_size = DEFAULT_INPUT_SIZE;
-/* default delay for phase-space reconstructions */
-#define DEFAULT_PHASE_SPACE_DELAY 10
-uint8_t phase_space_delay = DEFAULT_PHASE_SPACE_DELAY;
-/* default spline span size */
-#define DEFAULT_SPAN_SIZE 6
-uint8_t span_size = DEFAULT_SPAN_SIZE;
+
 /* volume scaling */
 double volume_scale = 1.0;
 
@@ -163,8 +158,6 @@ main(int argc, char **argv)
   /* Create context */
   context = Context_new(webcams);
   Context_set_input_size(context, input_size);
-  Context_set_phase_space_delay(context, phase_space_delay);
-  Context_set_span_size(context, span_size);
 
   biniou_set_max_fps(max_fps);
 
@@ -186,7 +179,7 @@ main(int argc, char **argv)
 #ifdef DEBUG
              |B_INIT_VERBOSE
 #endif
-             , input_size, phase_space_delay, span_size, webcams);
+             , input_size, webcams);
   xfree(themes);
 
   if (statistics) {
