@@ -98,7 +98,7 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
 
   Buffer8_t *dst = passive_buffer(ctx);
 
-  if (ctx->input == NULL) {
+  if (NULL == ctx->input) {
     printf("[!] Porteuse_draw called without input\n");
     return;
   }
@@ -152,7 +152,6 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
     xi += origin.x;
     yi += origin.y;
 
-    /* XXX TODO split off in two functions: draw_line & draw_dots */
     if (connect) {
       draw_line(dst, last.x, last.y, (short)xi, (short)yi, color);
     } else {
