@@ -32,7 +32,6 @@ struct Context_s;
 typedef struct Plugin_s {
   void   *handle;   /* .so handle */
 
-  uint32_t id;      /* creation date */
   uint32_t version; /* version to increase when exposed parameters change */
   u_long *options;
   u_long *mode;
@@ -54,7 +53,7 @@ typedef struct Plugin_s {
   int8_t   (*check_version)(uint32_t version);	 /* returns 0 if plugin is not compatible with version */
 
   void     (*run)(struct Context_s *);	         /* run function */
-  json_t * (*parameters)(json_t *);              /* parameters managment */
+  json_t * (*parameters)(struct Context_s *, json_t *); /* parameters managment */
   void *   (*jthread)(void *);                   /* joinable thread */
 
   void     (*on_switch_on)(struct Context_s *);  /* switching on */
@@ -81,12 +80,11 @@ void plugin_parameters_add_string_list(json_t *params_array, const char *name, u
 uint8_t plugin_parameter_parse_int(const json_t *in_parameters, const char *name, int *value);
 uint8_t plugin_parameter_parse_int_range(const json_t *in_parameters, const char *name, int *value, int vmin, int vmax);
 uint8_t plugin_parameter_parse_double(const json_t *in_parameters, const char *name, double *value);
-uint8_t plugin_parameter_parse_float(const json_t *in_parameters, const char *name, float *value);
-uint8_t plugin_parameter_parse_float_range(const json_t *in_parameters, const char *name, float *value, float vmin, float vmax);
+uint8_t plugin_parameter_parse_double_range(const json_t *in_parameters, const char *name, double *value, double vmin, double vmax);
 uint8_t plugin_parameter_find_string_in_list(const json_t *in_parameters, const char *name, int *value);
 uint8_t plugin_parameter_parse_string_list_as_int_range(const json_t *in_parameters, const char *name, uint32_t nb_elems, const char **elems, int *value, int vmin, int vmax);
 uint8_t plugin_parameter_parse_string(const json_t *in_parameters, const char *name, char **value);
-json_t *plugin_parameter_change_selected(const char *delta, const float factor);
+json_t *plugin_parameter_change_selected(struct Context_s *, const char *delta, const float factor);
 json_t *plugin_parameters_to_saved_parameters(json_t *in);
 
 #endif /* __BINIOU_PLUGIN_H */
