@@ -41,8 +41,7 @@ void Plugins_load(Plugins_t *, const Context_t *);
 void Plugins_init(Plugins_t *);
 void Plugins_reload_selected(Plugins_t *);
 
-Plugin_t *Plugins_find(const u_long);
-Plugin_t *Plugins_find_by_name(const char *);
+Plugin_t *Plugins_find(const char *);
 Plugin_t *Plugins_get_random(const enum PluginOptions, const Plugin_t *);
 
 void Plugins_select(Plugins_t *, const Plugin_t *);
@@ -54,9 +53,6 @@ void Plugins_prev_n(const u_short);
 
 int Plugins_event(Plugins_t *, const Event_t *);
 
-/* Use with extreme care, this is not for beginners */
-void Plugins_change_run_callback(const u_long, void (*)(struct Context_s *));
-
 void Plugins_set_blacklist(gchar **);
 
 #endif /* __BINIOU_PLUGINS_H */
