@@ -29,12 +29,12 @@
 Sequence_t *
 Sequence_load_json(const char *file)
 {
-  if (file == NULL) {
+  if (NULL == file) {
     xerror("Attempt to load a sequence with a NULL filename\n");
   }
 
   char *dot = strrchr(file, '.');
-  if ((dot == NULL) || strcasecmp(dot, ".json")) {
+  if ((NULL == dot) || strcasecmp(dot, ".json")) {
 #ifdef DEBUG
     VERBOSE(printf("[!] Not a sequence filename: '%s'\n", file));
 #endif
@@ -70,6 +70,7 @@ Sequence_load_json(const char *file)
   s = Sequence_new(json_integer_value(j_id));
   *dot = '\0';
   s->name = strdup(file);
+  *dot = '.';
 
   /* get auto_colormaps */
   json_t *j_auto_colormaps = json_object_get(parsed_json, "auto_colormaps");
@@ -120,7 +121,7 @@ Sequence_load_json(const char *file)
 #ifdef DEBUG
     printf("[i] Need image: '%s'\n", image);
 #endif
-    if (images == NULL) {
+    if (NULL == images) {
       VERBOSE(printf("[!] No images are loaded, won't find '%s'\n", image));
       goto error;
     } else {
@@ -130,7 +131,7 @@ Sequence_load_json(const char *file)
       }
     }
   } else {
-    if (images == NULL) {
+    if (NULL == images) {
       s->broken      = 1;
       s->image_id    = -1;
       s->auto_images = 0;
@@ -149,24 +150,21 @@ bare_sequence:
   for (u_short n = 0; n < n_plugins; n++) {
     json_t *j_p = json_array_get(j_plugins, n);
 
-    json_t *j_p_id = json_object_get(j_p, "id");
-    assert(NULL != j_p_id);
-    int id = json_integer_value(j_p_id);
-    if (!id) {
-      goto error;
-    }
+    json_t *j_p_name = json_object_get(j_p, "name");
+    assert(NULL != j_p_name);
 
     json_t *j_p_version = json_object_get(j_p, "version");
     assert(NULL != j_p_version);
     uint32_t version = json_integer_value(j_p_version);
 
-    Plugin_t *p = Plugins_find((u_long)id);
-    if (p == NULL) {
+    Plugin_t *p = Plugins_find(json_string_value(j_p_name));
+    if (NULL == p) {
+      VERBOSE(printf("[!] Could not find plugin %s\n", json_string_value(j_p_name)));
       goto error;
     }
 
     if (p->version != version) {
-      if (p->check_version != NULL && p->check_version(version) == 0) {
+      if ((NULL != p->check_version) && p->check_version(version) == 0) {
         VERBOSE(printf("[!] Plugin %s version is %d but trying to load from incompatible version %d\n",
                        p->name, p->version, version));
         goto error;
@@ -221,12 +219,12 @@ Sequence_load_xml(const char *file)
   xmlChar *youhou;
   int legacy = 0;
 
-  if (file == NULL) {
+  if (NULL == file) {
     xerror("Attempt to load a sequence with a NULL filename\n");
   }
 
   char *dot = strrchr(file, '.');
-  if ((dot == NULL) || strcasecmp(dot, ".xml")) {
+  if ((NULL == dot) || strcasecmp(dot, ".xml")) {
 #ifdef DEBUG
     printf("[!] Not a sequence filename: '%s'\n", file);
 #endif
@@ -248,18 +246,18 @@ Sequence_load_xml(const char *file)
 
   doc = xmlParseFile(blah);
   g_free(blah);
-  if (doc == NULL) {
+  if (NULL == doc) {
     xerror("xmlParseFile error\n");
   }
 
   sequence_node = xmlDocGetRootElement(doc);
-  if (sequence_node == NULL) {
+  if (NULL == sequence_node) {
     VERBOSE(printf("[!] Sequence %s: xmlDocGetRootElement error\n", file));
     goto error;
   }
 
   sequence_node = xmlFindElement("sequence", sequence_node);
-  if (sequence_node == NULL) {
+  if (NULL == sequence_node) {
     VERBOSE(printf("[!] Sequence %s: no <sequence> found\n", file));
     goto error;
   }
@@ -279,7 +277,7 @@ Sequence_load_xml(const char *file)
   sequence_node_save = sequence_node = sequence_node->xmlChildrenNode;
 
   sequence_node = xmlFindElement("auto_colormaps", sequence_node);
-  if (sequence_node == NULL) {
+  if (NULL == sequence_node) {
     sequence_node = sequence_node_save;
     goto bare_sequence;
   }
@@ -309,10 +307,10 @@ Sequence_load_xml(const char *file)
   /* then, get  <auto_images> or (legacy) <auto_pictures> */
   sequence_node_save = sequence_node = sequence_node->next;
   sequence_node = xmlFindElement("auto_images", sequence_node);
-  if (sequence_node == NULL) {
+  if (NULL == sequence_node) {
     sequence_node = sequence_node_save;
     sequence_node = xmlFindElement("auto_pictures", sequence_node);
-    if (sequence_node == NULL) {
+    if (NULL == sequence_node) {
       VERBOSE(printf("[!] Sequence %s: no <auto_images> or <auto_pictures> found\n", file));
       goto error;
     } else {
@@ -336,7 +334,7 @@ Sequence_load_xml(const char *file)
 #ifdef DEBUG
     printf("[i] Need image: '%s'\n", image);
 #endif
-    if (images == NULL) {
+    if (NULL == images) {
       VERBOSE(printf("[!] No images are loaded, won't find '%s'\n", image));
       xfree(image);
       goto error;
@@ -348,7 +346,7 @@ Sequence_load_xml(const char *file)
       xfree(image);
     }
   } else {
-    if (images == NULL) {
+    if (NULL == images) {
       s->broken      = 1;
       s->image_id    = -1;
       s->auto_images = 0;
@@ -360,33 +358,27 @@ Sequence_load_xml(const char *file)
 bare_sequence:
   /* now, get plugins */
   plugins_node = xmlFindElement("plugins", sequence_node);
-  if (plugins_node == NULL) {
+  if (NULL == plugins_node) {
     VERBOSE(printf("[!] Sequence %s: no <plugins> found\n", file));
     goto error;
   }
   plugins_node = plugins_node->xmlChildrenNode;
-  if (plugins_node == NULL) {
+  if (NULL == plugins_node) {
     VERBOSE(printf("[!] Sequence %s: no elements in <plugins>\n", file));
     goto error;
   }
 
-  while (plugins_node != NULL) {
+  while (NULL != plugins_node) {
     u_char   lens;
     Layer_t *layer;
     Plugin_t *p;
 
-    assert(plugins_node->name != NULL);
+    assert(NULL != plugins_node->name);
     lens = !xmlStrcmp(plugins_node->name, (const xmlChar *)"lens");
 
-    youhou = xmlGetProp(plugins_node, (const xmlChar *)"id");
-    tmp    = getintfield(youhou);
-    xmlFree(youhou);
-    if (!tmp) {
-      goto error;
-    }
-
-    p = Plugins_find((u_long)tmp);
-    if (p == NULL) {
+    youhou = xmlGetProp(plugins_node, (const xmlChar *)"name");
+    p = Plugins_find((const char *)youhou);
+    if (NULL == p) {
       goto error;
     }
 
@@ -395,7 +387,7 @@ bare_sequence:
     layer = Layer_new(p);
 
     youhou = xmlGetProp(plugins_node, (const xmlChar *)"mode");
-    if (youhou != NULL) {
+    if (NULL != youhou) {
       mode = LayerMode_from_string((const char *)youhou);
       xmlFree(youhou);
     } else {
@@ -440,7 +432,7 @@ Sequence_t *
 Sequence_load(const char *filename)
 {
   char *dot = strrchr(filename, '.');
-  if (dot != NULL) {
+  if (NULL != dot) {
     if (strncasecmp(dot, ".json", 5 * sizeof(char)) == 0) {
       return Sequence_load_json(filename);
     }
