@@ -48,19 +48,18 @@ Sequence_to_json(const Sequence_t *s, const uint8_t full)
   json_t *plugins_j = json_array();
 
   /* iterate over plugins list */
-  for (GList *layers = g_list_first(s->layers); layers != NULL; layers = g_list_next(layers)) {
+  for (GList *layers = g_list_first(s->layers); NULL != layers; layers = g_list_next(layers)) {
     Layer_t *layer = (Layer_t *)layers->data;
     Plugin_t *p = layer->plugin;
 
     json_t *j_plugin = json_object();
-    json_object_set_new(j_plugin, "lens", json_boolean((s->lens != NULL) && (p == s->lens)));
+    json_object_set_new(j_plugin, "lens", json_boolean((NULL != s->lens) && (p == s->lens)));
     json_object_set_new(j_plugin, "name", json_string(p->name));
-    json_object_set_new(j_plugin, "id", json_integer(p->id));
     json_object_set_new(j_plugin, "version", json_integer(p->version));
     json_object_set_new(j_plugin, "mode", json_string(LayerMode_to_string(layer->mode)));
 
     if (NULL != p->parameters) {
-      json_t *j_params = (json_t *)p->parameters(NULL);
+      json_t *j_params = (json_t *)p->parameters(NULL, NULL);
       json_object_set_new(j_plugin, "parameters", plugin_parameters_to_saved_parameters(j_params));
       json_decref(j_params);
     }
@@ -85,7 +84,7 @@ Sequence_write_json(const Sequence_t *s, const char *filename, const uint8_t ful
 
 
 void
-Sequence_save(Sequence_t *s, int overwrite, const int is_transient,
+Sequence_save(Context_t *ctx, Sequence_t *s, int overwrite, const int is_transient,
               const uint8_t bare, const char auto_colormaps, const char auto_images)
 {
   Sequence_t *store = NULL;
@@ -109,7 +108,7 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient,
     s->id = unix_timestamp();
   }
 
-  if (s->name == NULL) {
+  if (NULL == s->name) {
     s->name = g_strdup_printf("%" PRIu32, s->id);
   }
   printf("[s] Saving sequence %" PRIu32 "\n", s->id);
@@ -141,7 +140,7 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient,
   if (Sequence_write_json(s, filename_json, bare) == 0 && overwrite) {
     /* Erase old XML sequence */
     FILE *fp = fopen(filename_xml, "r");
-    if (fp != NULL) {
+    if (NULL != fp) {
       fclose(fp);
       if (remove(filename_xml) == 0) {
         printf("[s] Removed old XML sequence %s\n", filename_xml);
@@ -157,9 +156,9 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient,
     GList *oldp = g_list_find_custom(sequences->seqs, (gpointer)s, Sequence_sort_func);
     Sequence_t *old;
 
-    if (oldp != NULL) {
+    if (NULL != oldp) {
       old = (Sequence_t *)oldp->data;
-      Sequence_copy(s, old);
+      Sequence_copy(ctx, s, old);
     } else {
       overwrite = 0;
     }
@@ -168,7 +167,7 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient,
   if (overwrite == 0) {
     /* new sequence */
     store = Sequence_new(0);
-    Sequence_copy(s, store);
+    Sequence_copy(ctx, s, store);
 
     sequences->seqs = g_list_prepend(sequences->seqs, (gpointer)store);
     sequences->size++;
