@@ -68,7 +68,7 @@ SequenceManager_move_selected_front(Sequence_t *seq)
     return;
   }
 
-  if ((where = Sequence_find(seq, plugins->selected)) == NULL) {
+  if (NULL == (where = Sequence_find(seq, plugins->selected))) {
     return;
   }
 
@@ -103,7 +103,7 @@ SequenceManager_move_selected_back(Sequence_t *seq)
     return;
   }
 
-  if ((where = Sequence_find(seq, plugins->selected)) == NULL) {
+  if (NULL == (where = Sequence_find(seq, plugins->selected))) {
     return;
   }
 
@@ -145,12 +145,12 @@ SequenceManager_select_previous_plugin(Sequence_t *seq)
     const GList *hou = Sequence_find(seq, plugins->selected);
     const Plugin_t *P;
 
-    if (hou == NULL) {
+    if (NULL == hou) {
       /* Selected plugin not in sequence, selecting last layer */
       P = ((const Layer_t *)g_list_last(seq->layers)->data)->plugin;
     } else {
       hou = g_list_previous(hou);
-      if (hou == NULL) {
+      if (NULL == hou) {
         hou = g_list_last(seq->layers);
       }
       P = ((const Layer_t *)hou->data)->plugin;
@@ -167,12 +167,12 @@ SequenceManager_select_next_plugin(Sequence_t *seq)
     const GList *hou = Sequence_find(seq, plugins->selected);
     const Plugin_t *P;
 
-    if (hou == NULL) {
+    if (NULL == hou) {
       /* Selected plugin not in sequence, selecting first layer */
       P = ((const Layer_t *)g_list_first(seq->layers)->data)->plugin;
     } else {
       hou = g_list_next(hou);
-      if (hou == NULL) {
+      if (NULL == hou) {
         hou = g_list_first(seq->layers);
       }
       P = ((const Layer_t*)hou->data)->plugin;
@@ -187,7 +187,7 @@ SequenceManager_default_layer_mode(const Sequence_t *seq)
 {
   const GList *ptr = Sequence_find(seq, plugins->selected);
 
-  if (ptr != NULL) {
+  if (NULL != ptr) {
     Layer_t *layer = (Layer_t *)ptr->data;
     layer->mode = NORMAL;
   }
@@ -199,7 +199,7 @@ SequenceManager_prev_layer_mode(const Sequence_t *seq)
 {
   const GList *ptr = Sequence_find(seq, plugins->selected);
 
-  if (ptr != NULL) {
+  if (NULL != ptr) {
     Layer_t *layer = (Layer_t *)ptr->data;
     if (layer->mode == NONE) {
       layer->mode = RANDOM;
@@ -215,7 +215,7 @@ SequenceManager_next_layer_mode(const Sequence_t *seq)
 {
   const GList *ptr = Sequence_find(seq, plugins->selected);
 
-  if (ptr != NULL) {
+  if (NULL != ptr) {
     Layer_t *layer = (Layer_t *)ptr->data;
     if (layer->mode == RANDOM) {
       layer->mode = NONE;
@@ -224,3 +224,17 @@ SequenceManager_next_layer_mode(const Sequence_t *seq)
     }
   }
 }
+
+
+void
+SequenceManager_lock(SequenceManager_t *sm)
+{
+  pthread_mutex_lock(&sm->mutex);
+}
+
+
+void
+SequenceManager_unlock(SequenceManager_t *sm)
+{
+  pthread_mutex_unlock(&sm->mutex);
+}
