@@ -48,16 +48,18 @@ Spline_new(const uint8_t span, const int64_t nb_cpoints)
 void
 Spline_delete(Spline_t *s)
 {
-  uint8_t dd;
+  if (NULL != s) {
+    uint8_t dd;
 
-  xfree(s->cpoints);
-  xfree(s->spoints);
+    xfree(s->cpoints);
+    xfree(s->spoints);
 
-  for (dd = 0; dd < 8; dd++) {
-    xfree(s->space[dd]);
+    for (dd = 0; dd < 8; dd++) {
+      xfree(s->space[dd]);
+    }
+
+    xfree(s);
   }
-
-  xfree(s);
 }
 
 
@@ -162,7 +164,7 @@ Spline_compute(const Spline_t *s)
 void
 Spline_info(const Spline_t *s)
 {
-  if (s != NULL) {
+  if (NULL != s) {
     printf("[s] Spline has span: %d\n", s->span);
     printf("[s] %"PRIu64" control points\n", s->nb_cpoints);
     printf("[s] %"PRIu64" spline points\n", s->nb_spoints);
